@@ -11,7 +11,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.cdk
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.29.0", __name__, "aws-kms@0.29.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.30.0", __name__, "aws-kms@0.30.0.jsii.tgz")
 class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnAlias"):
     """A CloudFormation ``AWS::KMS::Alias``.
 
@@ -224,6 +224,151 @@ class CfnKeyProps(_CfnKeyProps):
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keypolicy
     """
 
+class EncryptionKey(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.EncryptionKey"):
+    """Defines a KMS key."""
+    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, retain: typing.Optional[bool]=None) -> None:
+        """
+        Arguments:
+            scope: -
+            id: -
+            props: -
+            description: A description of the key. Use a description that helps your users decide whether the key is appropriate for a particular task.
+            enabled: Indicates whether the key is available for use. Default: Key is enabled
+            enableKeyRotation: Indicates whether AWS KMS rotates the key. Default: false
+            policy: Custom policy document to attach to the KMS key. Default: A policy document with permissions for the account root to administer the key will be created.
+            retain: Whether the encryption key should be retained when it is removed from the Stack. This is useful when one wants to retain access to data that was encrypted with a key that is being retired. Default: true
+        """
+        props: EncryptionKeyProps = {}
+
+        if description is not None:
+            props["description"] = description
+
+        if enabled is not None:
+            props["enabled"] = enabled
+
+        if enable_key_rotation is not None:
+            props["enableKeyRotation"] = enable_key_rotation
+
+        if policy is not None:
+            props["policy"] = policy
+
+        if retain is not None:
+            props["retain"] = retain
+
+        jsii.create(EncryptionKey, self, [scope, id, props])
+
+    @jsii.member(jsii_name="import")
+    @classmethod
+    def import_(cls, scope: aws_cdk.cdk.Construct, id: str, *, key_arn: str) -> "IEncryptionKey":
+        """Defines an imported encryption key.
+
+        ``ref`` can be obtained either via a call to ``key.export()`` or using
+        literals.
+
+        For example:
+
+        const keyAttr = key.export();
+        const keyRef1 = EncryptionKey.import(this, 'MyImportedKey1', keyAttr);
+        const keyRef2 = EncryptionKey.import(this, 'MyImportedKey2', {
+        keyArn: new KeyArn('arn:aws:kms:...')
+        });
+
+        Arguments:
+            scope: The parent construct.
+            id: The name of the construct.
+            props: The key reference.
+            keyArn: The ARN of the external KMS key.
+        """
+        props: EncryptionKeyImportProps = {"keyArn": key_arn}
+
+        return jsii.sinvoke(cls, "import", [scope, id, props])
+
+    @jsii.member(jsii_name="addAlias")
+    def add_alias(self, alias: str) -> "EncryptionKeyAlias":
+        """Defines a new alias for the key.
+
+        Arguments:
+            alias: -
+        """
+        return jsii.invoke(self, "addAlias", [alias])
+
+    @jsii.member(jsii_name="addToResourcePolicy")
+    def add_to_resource_policy(self, statement: aws_cdk.aws_iam.PolicyStatement, allow_no_op: typing.Optional[bool]=None) -> None:
+        """Adds a statement to the KMS key resource policy.
+
+        Arguments:
+            statement: The policy statement to add.
+            allowNoOp: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
+        """
+        return jsii.invoke(self, "addToResourcePolicy", [statement, allow_no_op])
+
+    @jsii.member(jsii_name="export")
+    def export(self) -> "EncryptionKeyImportProps":
+        """Exports this key from the current stack.
+
+        Returns:
+            a key ref which can be used in a call to ``EncryptionKey.import(ref)``.
+        """
+        return jsii.invoke(self, "export", [])
+
+    @jsii.member(jsii_name="grant")
+    def grant(self, grantee: aws_cdk.aws_iam.IGrantable, *actions: str) -> aws_cdk.aws_iam.Grant:
+        """Grant the indicated permissions on this key to the given principal.
+
+        This modifies both the principal's policy as well as the resource policy,
+        since the default CloudFormation setup for KMS keys is that the policy
+        must not be empty and so default grants won't work.
+
+        Arguments:
+            grantee: -
+            actions: -
+        """
+        return jsii.invoke(self, "grant", [grantee, actions])
+
+    @jsii.member(jsii_name="grantDecrypt")
+    def grant_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        """Grant decryption permisisons using this key to the given principal.
+
+        Arguments:
+            grantee: -
+        """
+        return jsii.invoke(self, "grantDecrypt", [grantee])
+
+    @jsii.member(jsii_name="grantEncrypt")
+    def grant_encrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        """Grant encryption permisisons using this key to the given principal.
+
+        Arguments:
+            grantee: -
+        """
+        return jsii.invoke(self, "grantEncrypt", [grantee])
+
+    @jsii.member(jsii_name="grantEncryptDecrypt")
+    def grant_encrypt_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        """Grant encryption and decryption permisisons using this key to the given principal.
+
+        Arguments:
+            grantee: -
+        """
+        return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
+
+    @property
+    @jsii.member(jsii_name="keyArn")
+    def key_arn(self) -> str:
+        """The ARN of the key."""
+        return jsii.get(self, "keyArn")
+
+    @property
+    @jsii.member(jsii_name="policy")
+    def _policy(self) -> typing.Optional[aws_cdk.aws_iam.PolicyDocument]:
+        """Optional policy document that represents the resource policy of this key.
+
+        If specified, addToResourcePolicy can be used to edit this policy.
+        Otherwise this method will no-op.
+        """
+        return jsii.get(self, "policy")
+
+
 class EncryptionKeyAlias(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.EncryptionKeyAlias"):
     """Defines a display name for a customer master key (CMK) in AWS Key Management Service (AWS KMS).
 
@@ -475,214 +620,6 @@ class _IEncryptionKeyProxy(jsii.proxy_for(aws_cdk.cdk.IConstruct)):
         return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
 
 
-@jsii.implements(IEncryptionKey)
-class EncryptionKeyBase(aws_cdk.cdk.Construct, metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/aws-kms.EncryptionKeyBase"):
-    @staticmethod
-    def __jsii_proxy_class__():
-        return _EncryptionKeyBaseProxy
-
-    def __init__(self, scope: aws_cdk.cdk.Construct, id: str) -> None:
-        """Creates a new construct node.
-
-        Arguments:
-            scope: The scope in which to define this construct.
-            id: The scoped construct ID. Must be unique amongst siblings. If the ID includes a path separator (``/``), then it will be replaced by double dash ``--``.
-        """
-        jsii.create(EncryptionKeyBase, self, [scope, id])
-
-    @jsii.member(jsii_name="addAlias")
-    def add_alias(self, alias: str) -> "EncryptionKeyAlias":
-        """Defines a new alias for the key.
-
-        Arguments:
-            alias: -
-        """
-        return jsii.invoke(self, "addAlias", [alias])
-
-    @jsii.member(jsii_name="addToResourcePolicy")
-    def add_to_resource_policy(self, statement: aws_cdk.aws_iam.PolicyStatement, allow_no_op: typing.Optional[bool]=None) -> None:
-        """Adds a statement to the KMS key resource policy.
-
-        Arguments:
-            statement: The policy statement to add.
-            allowNoOp: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
-        """
-        return jsii.invoke(self, "addToResourcePolicy", [statement, allow_no_op])
-
-    @jsii.member(jsii_name="export")
-    @abc.abstractmethod
-    def export(self) -> "EncryptionKeyImportProps":
-        """Exports this key from the current stack."""
-        ...
-
-    @jsii.member(jsii_name="grant")
-    def grant(self, grantee: aws_cdk.aws_iam.IGrantable, *actions: str) -> aws_cdk.aws_iam.Grant:
-        """Grant the indicated permissions on this key to the given principal.
-
-        This modifies both the principal's policy as well as the resource policy,
-        since the default CloudFormation setup for KMS keys is that the policy
-        must not be empty and so default grants won't work.
-
-        Arguments:
-            grantee: -
-            actions: -
-        """
-        return jsii.invoke(self, "grant", [grantee, actions])
-
-    @jsii.member(jsii_name="grantDecrypt")
-    def grant_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
-        """Grant decryption permisisons using this key to the given principal.
-
-        Arguments:
-            grantee: -
-        """
-        return jsii.invoke(self, "grantDecrypt", [grantee])
-
-    @jsii.member(jsii_name="grantEncrypt")
-    def grant_encrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
-        """Grant encryption permisisons using this key to the given principal.
-
-        Arguments:
-            grantee: -
-        """
-        return jsii.invoke(self, "grantEncrypt", [grantee])
-
-    @jsii.member(jsii_name="grantEncryptDecrypt")
-    def grant_encrypt_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
-        """Grant encryption and decryption permisisons using this key to the given principal.
-
-        Arguments:
-            grantee: -
-        """
-        return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
-
-    @property
-    @jsii.member(jsii_name="keyArn")
-    @abc.abstractmethod
-    def key_arn(self) -> str:
-        """The ARN of the key."""
-        ...
-
-    @property
-    @jsii.member(jsii_name="policy")
-    @abc.abstractmethod
-    def _policy(self) -> typing.Optional[aws_cdk.aws_iam.PolicyDocument]:
-        """Optional policy document that represents the resource policy of this key.
-
-        If specified, addToResourcePolicy can be used to edit this policy.
-        Otherwise this method will no-op.
-        """
-        ...
-
-
-class _EncryptionKeyBaseProxy(EncryptionKeyBase):
-    @jsii.member(jsii_name="export")
-    def export(self) -> "EncryptionKeyImportProps":
-        """Exports this key from the current stack."""
-        return jsii.invoke(self, "export", [])
-
-    @property
-    @jsii.member(jsii_name="keyArn")
-    def key_arn(self) -> str:
-        """The ARN of the key."""
-        return jsii.get(self, "keyArn")
-
-    @property
-    @jsii.member(jsii_name="policy")
-    def _policy(self) -> typing.Optional[aws_cdk.aws_iam.PolicyDocument]:
-        """Optional policy document that represents the resource policy of this key.
-
-        If specified, addToResourcePolicy can be used to edit this policy.
-        Otherwise this method will no-op.
-        """
-        return jsii.get(self, "policy")
-
-
-class EncryptionKey(EncryptionKeyBase, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.EncryptionKey"):
-    """Defines a KMS key."""
-    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, retain: typing.Optional[bool]=None) -> None:
-        """
-        Arguments:
-            scope: -
-            id: -
-            props: -
-            description: A description of the key. Use a description that helps your users decide whether the key is appropriate for a particular task.
-            enabled: Indicates whether the key is available for use. Default: Key is enabled
-            enableKeyRotation: Indicates whether AWS KMS rotates the key. Default: false
-            policy: Custom policy document to attach to the KMS key. Default: A policy document with permissions for the account root to administer the key will be created.
-            retain: Whether the encryption key should be retained when it is removed from the Stack. This is useful when one wants to retain access to data that was encrypted with a key that is being retired. Default: true
-        """
-        props: EncryptionKeyProps = {}
-
-        if description is not None:
-            props["description"] = description
-
-        if enabled is not None:
-            props["enabled"] = enabled
-
-        if enable_key_rotation is not None:
-            props["enableKeyRotation"] = enable_key_rotation
-
-        if policy is not None:
-            props["policy"] = policy
-
-        if retain is not None:
-            props["retain"] = retain
-
-        jsii.create(EncryptionKey, self, [scope, id, props])
-
-    @jsii.member(jsii_name="import")
-    @classmethod
-    def import_(cls, scope: aws_cdk.cdk.Construct, id: str, *, key_arn: str) -> "IEncryptionKey":
-        """Defines an imported encryption key.
-
-        ``ref`` can be obtained either via a call to ``key.export()`` or using
-        literals.
-
-        For example:
-
-        const keyAttr = key.export();
-        const keyRef1 = EncryptionKey.import(this, 'MyImportedKey1', keyAttr);
-        const keyRef2 = EncryptionKey.import(this, 'MyImportedKey2', {
-        keyArn: new KeyArn('arn:aws:kms:...')
-        });
-
-        Arguments:
-            scope: The parent construct.
-            id: The name of the construct.
-            props: The key reference.
-            keyArn: The ARN of the external KMS key.
-        """
-        props: EncryptionKeyImportProps = {"keyArn": key_arn}
-
-        return jsii.sinvoke(cls, "import", [scope, id, props])
-
-    @jsii.member(jsii_name="export")
-    def export(self) -> "EncryptionKeyImportProps":
-        """Exports this key from the current stack.
-
-        Returns:
-            a key ref which can be used in a call to ``EncryptionKey.import(ref)``.
-        """
-        return jsii.invoke(self, "export", [])
-
-    @property
-    @jsii.member(jsii_name="keyArn")
-    def key_arn(self) -> str:
-        """The ARN of the key."""
-        return jsii.get(self, "keyArn")
-
-    @property
-    @jsii.member(jsii_name="policy")
-    def _policy(self) -> typing.Optional[aws_cdk.aws_iam.PolicyDocument]:
-        """Optional policy document that represents the resource policy of this key.
-
-        If specified, addToResourcePolicy can be used to edit this policy.
-        Otherwise this method will no-op.
-        """
-        return jsii.get(self, "policy")
-
-
 class ViaServicePrincipal(aws_cdk.aws_iam.PrincipalBase, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.ViaServicePrincipal"):
     """A principal to allow access to a key if it's being used through another AWS service."""
     def __init__(self, service_name: str, base_principal: typing.Optional[aws_cdk.aws_iam.IPrincipal]=None) -> None:
@@ -705,6 +642,6 @@ class ViaServicePrincipal(aws_cdk.aws_iam.PrincipalBase, metaclass=jsii.JSIIMeta
         return jsii.get(self, "serviceName")
 
 
-__all__ = ["CfnAlias", "CfnAliasProps", "CfnKey", "CfnKeyProps", "EncryptionKey", "EncryptionKeyAlias", "EncryptionKeyAliasProps", "EncryptionKeyBase", "EncryptionKeyImportProps", "EncryptionKeyProps", "IEncryptionKey", "ViaServicePrincipal", "__jsii_assembly__"]
+__all__ = ["CfnAlias", "CfnAliasProps", "CfnKey", "CfnKeyProps", "EncryptionKey", "EncryptionKeyAlias", "EncryptionKeyAliasProps", "EncryptionKeyImportProps", "EncryptionKeyProps", "IEncryptionKey", "ViaServicePrincipal", "__jsii_assembly__"]
 
 publication.publish()
